@@ -2,14 +2,14 @@
 # @Time    : 20211119 23:09
 # @Author  : yanbo92
 
-from _header import Header
-from _exception_information import ExceptionInformation
-from _diagnostic_message import DiagnosticMessage
-from _exception_backtrace import ExceptionBacktrace
-from _thread_0_backtrace import BacktraceForThread0
-from _other_threads_backtrace import BacktraceForAllThreads
-from _crashed_thread_state import CrashThreadState
-from _binary_image import BinaryImage
+from crash2json._header import Header
+from crash2json._exception_information import ExceptionInformation
+from crash2json._diagnostic_message import DiagnosticMessage
+from crash2json._exception_backtrace import ExceptionBacktrace
+from crash2json._thread_0_backtrace import BacktraceForThread0
+from crash2json._other_threads_backtrace import BacktraceForAllThreads
+from crash2json._crashed_thread_state import CrashThreadState
+from crash2json._binary_image import BinaryImage
 from collections import OrderedDict
 import os
 import json
